@@ -7,6 +7,7 @@
 //! Check out the [github examples](https://github.com/tiby312/poloto/tree/master/examples).
 //! The latest graph outputs of the examples can be found in the [assets](https://github.com/tiby312/poloto/tree/master/assets) folder.
 //!
+//!
 
 #[cfg(doctest)]
 mod test_readme {
@@ -27,8 +28,8 @@ pub use tagger::upgrade_write;
 pub use crop::Crop;
 pub use crop::Croppable;
 mod crop;
-
 mod render;
+pub mod tick_fmt;
 
 pub mod util;
 
@@ -88,6 +89,7 @@ enum PlotType {
     Line,
     Histo,
     LineFill,
+    LineFillRaw
 }
 
 struct Plot<'a, X: PlotNum, Y: PlotNum> {
@@ -98,7 +100,7 @@ struct Plot<'a, X: PlotNum, Y: PlotNum> {
 ///
 /// Default SVG Header for a Poloto graph.
 ///
-pub const SVG_HEADER: &str = r##"<svg class="poloto_background poloto" width="800" height="500" viewBox="0 0 800 500" xmlns="http://www.w3.org/2000/svg">"##;
+pub const SVG_HEADER: &str = r##"<svg class="poloto" width="800" height="500" viewBox="0 0 800 500" xmlns="http://www.w3.org/2000/svg">"##;
 
 ///
 /// Default SVG end tag.
@@ -110,12 +112,12 @@ pub const STYLE_CONFIG_LIGHT_DEFAULT: &str = ".poloto { \
     stroke-linecap:round; \
     stroke-linejoin:round; \
     font-family: 'Tahoma', sans-serif; \
-    stroke-width:2; \
+    background-color: AliceBlue;\
     } \
     .poloto_scatter{stroke-width:7} \
+    .poloto_line{stroke-width:2} \
     .poloto_text{fill: black;} \
     .poloto_axis_lines{stroke: black;stroke-width:3;fill:none;stroke-dasharray:none} \
-    .poloto_background{background-color: AliceBlue;} \
     .poloto0stroke{stroke:  blue;} \
     .poloto1stroke{stroke:  red;} \
     .poloto2stroke{stroke:  green;} \
@@ -138,12 +140,12 @@ pub const STYLE_CONFIG_DARK_DEFAULT: &str = ".poloto { \
     stroke-linecap:round; \
     stroke-linejoin:round; \
     font-family: 'Tahoma', sans-serif; \
-    stroke-width:2; \
+    background-color: #262626;\
     } \
     .poloto_scatter{stroke-width:7} \
+    .poloto_line{stroke-width:2} \
     .poloto_text{fill: white;} \
     .poloto_axis_lines{stroke: white;stroke-width:3;fill:none;stroke-dasharray:none} \
-    .poloto_background{background-color: #262626;} \
     .poloto0stroke{stroke:  blue;} \
     .poloto1stroke{stroke:  red;} \
     .poloto2stroke{stroke:  green;} \
@@ -334,6 +336,32 @@ impl<'a, X: PlotNum, Y: PlotNum> Plotter<'a, X, Y> {
         self
     }
 
+
+    /// Create a line from plots that will be filled using a SVG path element.
+    /// The first and last points will be connected and then filled in.
+    /// The path element belongs to the `.poloto[N]fill` css class.
+    ///
+    /// ```
+    /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
+    /// let mut plotter = poloto::plot("title", "x", "y");
+    /// plotter.line_fill_raw("", &data);
+    /// ```
+    pub fn line_fill_raw<I>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
+    where
+        I: IntoIterator,
+        I::IntoIter: Clone + 'a,
+        I::Item: Plottable<X, Y>,
+    {
+        self.plots.push(Plot {
+            plot_type: PlotType::LineFillRaw,
+            plots: Box::new(PlotStruct::new(
+                plots.into_iter().map(|x| x.make_plot()),
+                name,
+            )),
+        });
+        self
+    }
+
     /// Create a scatter plot from plots, using a SVG path with lines with zero length.
     /// Each point can be sized using the stroke width.
     /// The path belongs to the CSS classes `poloto_scatter` and `.poloto[N]stroke` css class
